@@ -149,7 +149,7 @@ class TCP(Comm):
 
     def __init__(self, stream, local_addr, peer_addr, deserialize=True):
         self._closed = False
-        Comm.__init__(self)
+        super().__init__()
         self._local_addr = local_addr
         self._peer_addr = peer_addr
         self.stream = stream
@@ -504,7 +504,7 @@ class BaseTCPListener(Listener, RequireEncryptionMixin):
         try:
             await self.on_connection(comm)
         except CommClosedError:
-            logger.info("Connection closed before handshake completed")
+            logger.info("Connection from %s closed before handshake completed", address)
             return
 
         await self.comm_handler(comm)
